@@ -19,6 +19,7 @@ COPY_SHA1 = hotkey(Qt.CTRL + Qt.ALT + Qt.Key_C)
 DIFFSTAT = hotkey(Qt.ALT + Qt.Key_D)
 DIFF = hotkey(Qt.CTRL + Qt.Key_D)
 DIFF_SECONDARY = hotkey(Qt.CTRL + Qt.SHIFT + Qt.Key_D)
+EDIT_SHORT = hotkey(Qt.Key_E)
 EDIT = hotkey(Qt.CTRL + Qt.Key_E)
 EDIT_SECONDARY = hotkey(Qt.CTRL + Qt.SHIFT + Qt.Key_E)
 EXPORT = hotkey(Qt.ALT + Qt.SHIFT + Qt.Key_E)
@@ -84,7 +85,7 @@ ZOOM_IN_SECONDARY = hotkey(Qt.Key_Equal)
 QUESTION = hotkey(Qt.Key_Question)
 RETURN = hotkey(Qt.Key_Return)
 ACCEPT = (ENTER, RETURN)
-COMMIT = hotkey(Qt.CTRL + Qt.Key_Return)
+APPLY = hotkey(Qt.CTRL + Qt.Key_Return)
 PREPARE_COMMIT_MESSAGE = hotkey(Qt.CTRL + Qt.SHIFT + Qt.Key_Return)
 PRIMARY_ACTION = hotkey(hotkey(Qt.Key_Space))
 SECONDARY_ACTION = hotkey(Qt.SHIFT + Qt.Key_Space)
