@@ -43,7 +43,6 @@ class ExpandingTabBar(QtWidgets.QTabBar):
 
 
 class ExpandingTabWidget(QtWidgets.QTabWidget):
-
     def __init__(self, parent=None):
         super(ExpandingTabWidget, self).__init__(parent)
         self.setTabBar(ExpandingTabBar(self))
@@ -97,17 +96,25 @@ class AboutView(QtWidgets.QDialog):
         self.close_button = qtutils.close_button()
         self.close_button.setDefault(True)
 
-        self.logo_layout = qtutils.hbox(defs.no_margin, defs.button_spacing,
-                                        self.logo_label, self.logo_text_label,
-                                        qtutils.STRETCH)
+        self.logo_layout = qtutils.hbox(
+            defs.no_margin,
+            defs.button_spacing,
+            self.logo_label,
+            self.logo_text_label,
+            qtutils.STRETCH,
+        )
 
-        self.button_layout = qtutils.hbox(defs.spacing, defs.margin,
-                                          qtutils.STRETCH, self.close_button)
+        self.button_layout = qtutils.hbox(
+            defs.spacing, defs.margin, qtutils.STRETCH, self.close_button
+        )
 
-        self.main_layout = qtutils.vbox(defs.no_margin, defs.spacing,
-                                        self.logo_layout,
-                                        self.tabs,
-                                        self.button_layout)
+        self.main_layout = qtutils.vbox(
+            defs.no_margin,
+            defs.spacing,
+            self.logo_layout,
+            self.tabs,
+            self.button_layout,
+        )
         self.setLayout(self.main_layout)
 
         qtutils.connect_button(self.close_button, self.accept)
@@ -119,7 +126,7 @@ def copyright_text():
     return """
 Git Cola: The highly caffeinated Git GUI
 
-Copyright (C) 2007-2018 David Aguilar and contributors
+Copyright (C) 2007-2020 David Aguilar and contributors
 
 This program is free software: you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -173,9 +180,12 @@ def version_text(context):
         python_path=python_path,
         python_version=python_version,
         qt_version=qt_version,
-        qtpy_version=qtpy_version)
+        qtpy_version=qtpy_version,
+    )
 
-    return N_("""
+    return (
+        N_(
+            """
         <br>
             Git Cola version %(cola_version)s %(build_version)s
         <ul>
@@ -186,7 +196,10 @@ def version_text(context):
             <li> QtPy %(qtpy_version)s
             <li> %(pyqt_api_name)s %(pyqt_api_version)s
         </ul>
-    """) % scope
+    """
+        )
+        % scope
+    )
 
 
 def link(url, text, palette=None):
@@ -197,12 +210,15 @@ def link(url, text, palette=None):
     rgb = 'rgb(%s, %s, %s)' % (color.red(), color.green(), color.blue())
     scope = dict(rgb=rgb, text=text, url=url)
 
-    return """
+    return (
+        """
         <a style="font-style: italic; text-decoration: none; color: %(rgb)s;"
             href="%(url)s">
             %(text)s
         </a>
-    """ % scope
+    """
+        % scope
+    )
 
 
 def mailto(email, text, palette):
@@ -214,13 +230,19 @@ def render_authors(authors):
     for x in authors:
         x.setdefault('email', '')
 
-    entries = [("""
+    entries = [
+        (
+            """
         <p>
             <strong>%(name)s</strong><br>
             <em>%(title)s</em><br>
             %(email)s
         </p>
-    """ % author) for author in authors]
+    """
+            % author
+        )
+        for author in authors
+    ]
 
     return ''.join(entries)
 
@@ -229,11 +251,14 @@ def contributors_text(authors, prelude='', epilogue=''):
     author_text = render_authors(authors)
     scope = dict(author_text=author_text, epilogue=epilogue, prelude=prelude)
 
-    return """
+    return (
+        """
         %(prelude)s
         %(author_text)s
         %(epilogue)s
-    """ % scope
+    """
+        % scope
+    )
 
 
 def authors_text():
@@ -246,37 +271,50 @@ def authors_text():
         # email address in the about screen.
         # See the `generate-about` script in the "todo" branch.
         # vim :read! ./Meta/generate-about
-        dict(name='David Aguilar',
-             title=N_('Maintainer (since 2007) and developer'),
-             email=mailto('davvid@gmail.com', contact, palette)),
+        dict(
+            name='David Aguilar',
+            title=N_('Maintainer (since 2007) and developer'),
+            email=mailto('davvid@gmail.com', contact, palette),
+        ),
         dict(name='Daniel Harding', title=N_('Developer')),
-        dict(name='Ｖ字龍(Vdragon)', title=N_('Developer'),
-             email=mailto('Vdragon.Taiwan@gmail.com', contact, palette)),
+        dict(
+            name='Ｖ字龍(Vdragon)',
+            title=N_('Developer'),
+            email=mailto('Vdragon.Taiwan@gmail.com', contact, palette),
+        ),
         dict(name='Efimov Vasily', title=N_('Developer')),
         dict(name='Guillaume de Bure', title=N_('Developer')),
+        dict(name='Javier Rodriguez Cuevas', title=N_('Developer')),
         dict(name='Uri Okrent', title=N_('Developer')),
         dict(name='Alex Chernetz', title=N_('Developer')),
+        dict(name='xhl', title=N_('Developer')),
         dict(name='Andreas Sommer', title=N_('Developer')),
         dict(name='Thomas Kluyver', title=N_('Developer')),
-        dict(name='Javier Rodriguez Cuevas', title=N_('Developer')),
         dict(name='Minarto Margoliono', title=N_('Developer')),
         dict(name='Szymon Judasz', title=N_('Developer')),
         dict(name='Ville Skyttä', title=N_('Developer')),
+        dict(name='jm4R', title=N_('Developer')),
         dict(name='Igor Galarraga', title=N_('Developer')),
         dict(name='Stanislaw Halik', title=N_('Developer')),
         dict(name='Virgil Dupras', title=N_('Developer')),
         dict(name='Barry Roberts', title=N_('Developer')),
         dict(name='wsdfhjxc', title=N_('Developer')),
-        dict(name='xhl', title=N_('Developer')),
+        dict(name='林博仁(Buo-ren Lin)', title=N_('Developer')),
+        dict(name='Guo Yunhe', title=N_('Developer')),
+        dict(name='cclauss', title=N_('Developer')),
         dict(name='Stefan Naewe', title=N_('Developer')),
+        dict(name='Victor Nepveu', title=N_('Developer')),
         dict(name='Benedict Lee', title=N_('Developer')),
         dict(name='Filip Danilović', title=N_('Developer')),
+        dict(name='NotSqrt', title=N_('Developer')),
         dict(name='Pavel Rehak', title=N_('Developer')),
         dict(name='Steffen Prohaska', title=N_('Developer')),
+        dict(name='Tim Brown', title=N_('Developer')),
         dict(name='Michael Geddes', title=N_('Developer')),
         dict(name='Rustam Safin', title=N_('Developer')),
         dict(name='Alex Gulyás', title=N_('Developer')),
         dict(name='David Martínez Martí', title=N_('Developer')),
+        dict(name='Hualiang Xie', title=N_('Developer')),
         dict(name='Justin Lecher', title=N_('Developer')),
         dict(name='Kai Krakow', title=N_('Developer')),
         dict(name='Karl Bielefeldt', title=N_('Developer')),
@@ -284,12 +322,14 @@ def authors_text():
         dict(name='Michael Homer', title=N_('Developer')),
         dict(name='Sebastian Schuberth', title=N_('Developer')),
         dict(name='Sven Claussner', title=N_('Developer')),
+        dict(name='bsomers', title=N_('Developer')),
         dict(name='real', title=N_('Developer')),
         dict(name='v.paritskiy', title=N_('Developer')),
-        dict(name='林博仁(Buo-ren Lin)', title=N_('Developer')),
+        dict(name='0xflotus', title=N_('Developer')),
         dict(name='AJ Bagwell', title=N_('Developer')),
         dict(name='Adrien be', title=N_('Developer')),
         dict(name='Andrej', title=N_('Developer')),
+        dict(name='Arthur Coelho', title=N_('Developer')),
         dict(name='Audrius Karabanovas', title=N_('Developer')),
         dict(name='Barrett Lowe', title=N_('Developer')),
         dict(name='Ben Boeckel', title=N_('Developer')),
@@ -300,6 +340,7 @@ def authors_text():
         dict(name='Daniel King', title=N_('Developer')),
         dict(name='Daniel Pavel', title=N_('Developer')),
         dict(name='David Zumbrunnen', title=N_('Developer')),
+        dict(name='Felipe Morales', title=N_('Developer')),
         dict(name='George Vasilakos', title=N_('Developer')),
         dict(name='Ilya Tumaykin', title=N_('Developer')),
         dict(name='Iulian Udrea', title=N_('Developer')),
@@ -307,6 +348,7 @@ def authors_text():
         dict(name='Jakub Szymański', title=N_('Developer')),
         dict(name='Jamie Pate', title=N_('Developer')),
         dict(name='Jean-Francois Dagenais', title=N_('Developer')),
+        dict(name='Joachim Lusiardi', title=N_('Developer')),
         dict(name='Karthik Manamcheri', title=N_('Developer')),
         dict(name='Kelvie Wong', title=N_('Developer')),
         dict(name='Kyle', title=N_('Developer')),
@@ -324,9 +366,12 @@ def authors_text():
         dict(name='Philip Stark', title=N_('Developer')),
         dict(name='Radek Postołowicz', title=N_('Developer')),
         dict(name='Rainer Müller', title=N_('Developer')),
+        dict(name='Ricardo J. Barberis', title=N_('Developer')),
         dict(name='Rolando Espinoza', title=N_('Developer')),
         dict(name="Samsul Ma'arif", title=N_('Developer')),
         dict(name='Sebastian Brass', title=N_('Developer')),
+        dict(name='Simon Peeters', title=N_('Developer')),
+        dict(name='Stephen', title=N_('Developer')),
         dict(name='Vaibhav Sagar', title=N_('Developer')),
         dict(name='Ved Vyas', title=N_('Developer')),
         dict(name='Voicu Hodrea', title=N_('Developer')),
@@ -339,11 +384,16 @@ def authors_text():
     bug_url = 'https://github.com/git-cola/git-cola/issues'
     bug_link = link(bug_url, bug_url)
     scope = dict(bug_link=bug_link)
-    prelude = N_("""
+    prelude = (
+        N_(
+            """
         <br>
         Please use %(bug_link)s to report issues.
         <br>
-    """) % scope
+    """
+        )
+        % scope
+    )
 
     return contributors_text(authors, prelude=prelude)
 
@@ -355,58 +405,55 @@ def translators_text():
     translators = (
         # See the `generate-about` script in the "todo" branch.
         # vim :read! ./Meta/generate-about --translators
-        dict(name='Ｖ字龍(Vdragon)',
-             title=N_('Traditional Chinese (Taiwan) translation'),
-             email=mailto('Vdragon.Taiwan@gmail.com', contact, palette)),
-        dict(name='Pavel Rehak',
-             title=N_('Czech translation')),
-        dict(name='Vitor Lobo',
-             title=N_('Brazilian translation')),
-        dict(name='Zhang Han',
-             title=N_('Simplified Chinese translation')),
-        dict(name='Igor Kopach',
-             title=N_('Ukranian translation')),
-        dict(name='Barış ÇELİK',
-             title=N_('Turkish translation')),
-        dict(name='Minarto Margoliono',
-             title=N_('Indonesian translation')),
-        dict(name='Rafael Nascimento',
-             title=N_('Brazilian translation')),
-        dict(name='Sven Claussner',
-             title=N_('German translation')),
-        dict(name='Vaiz',
-             title=N_('Russian translation')),
-        dict(name='Victorhck',
-             title=N_('Spanish translation')),
-        dict(name='Guo Yunhe',
-             title=N_('Simplified Chinese translation')),
-        dict(name='Kai Krakow',
-             title=N_('German translation')),
-        dict(name='Louis Rousseau',
-             title=N_('French translation')),
-        dict(name='Mickael Albertus',
-             title=N_('French translation')),
-        dict(name='Peter Dave Hello',
-             title=N_('Traditional Chinese (Taiwan) translation')),
-        dict(name='Pilar Molina Lopez',
-             title=N_('Spanish translation')),
-        dict(name="Samsul Ma'arif",
-             title=N_('Indonesian translation')),
-        dict(name='Zeioth',
-             title=N_('Spanish translation')),
-        dict(name='balping',
-             title=N_('Hungarian translation')),
-        dict(name='p-bo',
-             title=N_('Czech translation')),
-        dict(name='Łukasz Wojniłowicz',
-             title=N_('Polish translation')),
+        dict(
+            name='Ｖ字龍(Vdragon)',
+            title=N_('Traditional Chinese (Taiwan) translation'),
+            email=mailto('Vdragon.Taiwan@gmail.com', contact, palette),
+        ),
+        dict(name='Pavel Rehak', title=N_('Czech translation')),
+        dict(name='Victorhck', title=N_('Spanish translation')),
+        dict(name='Vitor Lobo', title=N_('Brazilian translation')),
+        dict(name='Zhang Han', title=N_('Simplified Chinese translation')),
+        dict(name='Igor Kopach', title=N_('Ukranian translation')),
+        dict(name='Barış ÇELİK', title=N_('Turkish translation')),
+        dict(name='Guo Yunhe', title=N_('Simplified Chinese translation')),
+        dict(name='Minarto Margoliono', title=N_('Indonesian translation')),
+        dict(name='Rafael Nascimento', title=N_('Brazilian translation')),
+        dict(name='Shun Sakai', title=N_('Japanese translation')),
+        dict(name='Sven Claussner', title=N_('German translation')),
+        dict(name='Vaiz', title=N_('Russian translation')),
+        dict(name='adlgrbz', title=N_('Turkish translation')),
+        dict(name='fu7mu4', title=N_('Japanese translation')),
+        dict(name='Gyuris Gellért', title=N_('Hungarian translation')),
+        dict(name='Joachim Lusiardi', title=N_('German translation')),
+        dict(name='Kai Krakow', title=N_('German translation')),
+        dict(name='Louis Rousseau', title=N_('French translation')),
+        dict(name='Mickael Albertus', title=N_('French translation')),
+        dict(
+            name='Peter Dave Hello',
+            title=N_('Traditional Chinese (Taiwan) translation'),
+        ),
+        dict(name='Pilar Molina Lopez', title=N_('Spanish translation')),
+        dict(name='Rafael Reuber', title=N_('Brazilian translation')),
+        dict(name='Sabri Ünal', title=N_('Turkish translation')),
+        dict(name="Samsul Ma'arif", title=N_('Indonesian translation')),
+        dict(name='Zeioth', title=N_('Spanish translation')),
+        dict(name='balping', title=N_('Hungarian translation')),
+        dict(name='p-bo', title=N_('Czech translation')),
+        dict(name='Łukasz Wojniłowicz', title=N_('Polish translation')),
+        dict(
+            name='林博仁(Buo-ren Lin)',
+            title=N_('Traditional Chinese (Taiwan) translation'),
+        ),
     )
 
     bug_url = 'https://github.com/git-cola/git-cola/issues'
     bug_link = link(bug_url, bug_url)
     scope = dict(bug_link=bug_link)
 
-    prelude = N_("""
+    prelude = (
+        N_(
+            """
         <br>
             Git Cola has been translated into different languages thanks
             to the help of the individuals listed below.
@@ -429,14 +476,17 @@ def translators_text():
 
         <br>
 
-    """) % scope
+    """
+        )
+        % scope
+    )
     return contributors_text(translators, prelude=prelude)
 
 
 def show_shortcuts():
     hotkeys_html = resources.doc(N_('hotkeys.html'))
     try:
-        from qtpy import QtWebEngineWidgets
+        from qtpy import QtWebEngineWidgets  # pylint: disable=all
     except (ImportError, qtpy.PythonQtError):
         # redhat disabled QtWebKit in their qt build but don't punish the users
         webbrowser.open_new_tab('file://' + hotkeys_html)
@@ -445,17 +495,18 @@ def show_shortcuts():
     html = core.read(hotkeys_html)
 
     parent = qtutils.active_window()
-    widget = QtWidgets.QDialog()
+    widget = QtWidgets.QDialog(parent)
     widget.setWindowModality(Qt.WindowModal)
     widget.setWindowTitle(N_('Shortcuts'))
 
-    web = QtWebEngineWidgets.QWebEngineView(parent)
+    web = QtWebEngineWidgets.QWebEngineView()
     web.setHtml(html)
 
     layout = qtutils.hbox(defs.no_margin, defs.spacing, web)
     widget.setLayout(layout)
     widget.resize(800, min(parent.height(), 600))
-    qtutils.add_action(widget, N_('Close'), widget.accept,
-                       hotkeys.QUESTION, *hotkeys.ACCEPT)
+    qtutils.add_action(
+        widget, N_('Close'), widget.accept, hotkeys.QUESTION, *hotkeys.ACCEPT
+    )
     widget.show()
     widget.exec_()
