@@ -34,8 +34,8 @@ class WidgetMixin(object):
             return
         left = parent.x()
         width = parent.width()
-        center_x = left + width//2
-        x = center_x - self.width()//2
+        center_x = left + width // 2
+        x = center_x - self.width() // 2
         y = parent.y()
 
         self.move(x, y)
@@ -144,7 +144,6 @@ class WidgetMixin(object):
 
 
 class MainWindowMixin(WidgetMixin):
-
     def __init__(self):
         WidgetMixin.__init__(self)
         # Dockwidget options
@@ -157,8 +156,7 @@ class MainWindowMixin(WidgetMixin):
     def init_state(self, settings, callback, *args, **kwargs):
         """Save the initial state before calling the parent initializer"""
         self.default_state = self.saveState(self.widget_version)
-        super(MainWindowMixin, self).init_state(settings, callback, *args,
-                                                **kwargs)
+        super(MainWindowMixin, self).init_state(settings, callback, *args, **kwargs)
 
     def export_state(self):
         """Exports data for save/restore"""
@@ -181,9 +179,12 @@ class MainWindowMixin(WidgetMixin):
         windowstate = state.get('windowstate', '')
         if windowstate:
             from_base64 = QtCore.QByteArray.fromBase64
-            result = self.restoreState(
-                from_base64(core.encode(windowstate)),
-                self.widget_version) and result
+            result = (
+                self.restoreState(
+                    from_base64(core.encode(windowstate)), self.widget_version
+                )
+                and result
+            )
         else:
             result = False
 
@@ -202,12 +203,13 @@ class MainWindowMixin(WidgetMixin):
 
     def update_dockwidget_lock_state(self):
         if self.lock_layout:
-            features = (QDockWidget.DockWidgetClosable |
-                        QDockWidget.DockWidgetFloatable)
+            features = QDockWidget.DockWidgetClosable | QDockWidget.DockWidgetFloatable
         else:
-            features = (QDockWidget.DockWidgetClosable |
-                        QDockWidget.DockWidgetFloatable |
-                        QDockWidget.DockWidgetMovable)
+            features = (
+                QDockWidget.DockWidgetClosable
+                | QDockWidget.DockWidgetFloatable
+                | QDockWidget.DockWidgetMovable
+            )
         for widget in self.dockwidgets:
             widget.titleBarWidget().update_tooltips()
             widget.setFeatures(features)
@@ -225,12 +227,20 @@ class ListWidget(QtWidgets.QListWidget):
         super(ListWidget, self).__init__(parent)
 
         self.up_action = qtutils.add_action(
-            self, N_('Move Up'), self.move_up,
-            hotkeys.MOVE_UP, hotkeys.MOVE_UP_SECONDARY)
+            self,
+            N_('Move Up'),
+            self.move_up,
+            hotkeys.MOVE_UP,
+            hotkeys.MOVE_UP_SECONDARY,
+        )
 
         self.down_action = qtutils.add_action(
-            self, N_('Move Down'), self.move_down,
-            hotkeys.MOVE_DOWN, hotkeys.MOVE_DOWN_SECONDARY)
+            self,
+            N_('Move Down'),
+            self.move_down,
+            hotkeys.MOVE_DOWN,
+            hotkeys.MOVE_DOWN_SECONDARY,
+        )
 
     def selected_item(self):
         return self.currentItem()
@@ -258,7 +268,6 @@ class ListWidget(QtWidgets.QListWidget):
 
 
 class TreeMixin(object):
-
     def __init__(self, widget, Base):
         self.widget = widget
         self.Base = Base
@@ -294,24 +303,16 @@ class TreeMixin(object):
 
         # Remap 'H' to 'Left'
         if key == Qt.Key_H:
-            event = QtGui.QKeyEvent(event.type(),
-                                    Qt.Key_Left,
-                                    event.modifiers())
+            event = QtGui.QKeyEvent(event.type(), Qt.Key_Left, event.modifiers())
         # Remap 'J' to 'Down'
         elif key == Qt.Key_J:
-            event = QtGui.QKeyEvent(event.type(),
-                                    Qt.Key_Down,
-                                    event.modifiers())
+            event = QtGui.QKeyEvent(event.type(), Qt.Key_Down, event.modifiers())
         # Remap 'K' to 'Up'
         elif key == Qt.Key_K:
-            event = QtGui.QKeyEvent(event.type(),
-                                    Qt.Key_Up,
-                                    event.modifiers())
+            event = QtGui.QKeyEvent(event.type(), Qt.Key_Up, event.modifiers())
         # Remap 'L' to 'Right'
         elif key == Qt.Key_L:
-            event = QtGui.QKeyEvent(event.type(),
-                                    Qt.Key_Right,
-                                    event.modifiers())
+            event = QtGui.QKeyEvent(event.type(), Qt.Key_Right, event.modifiers())
 
         # Re-read the event key to take the remappings into account
         key = event.key()
@@ -334,8 +335,7 @@ class TreeMixin(object):
         widget.index_about_to_change.emit()
 
         # Automatically select the first entry when expanding a directory
-        if (key == Qt.Key_Right and was_collapsed and
-                widget.isExpanded(index)):
+        if key == Qt.Key_Right and was_collapsed and widget.isExpanded(index):
             index = widget.moveCursor(widget.MoveDown, event.modifiers())
             widget.setCurrentIndex(index)
 
@@ -344,8 +344,10 @@ class TreeMixin(object):
 
             # File entries have rowCount() == 0
             model = widget.model()
-            if (hasattr(model, 'itemFromIndex')
-                    and model.itemFromIndex(index).rowCount() == 0):
+            if (
+                hasattr(model, 'itemFromIndex')
+                and model.itemFromIndex(index).rowCount() == 0
+            ):
                 widget.setCurrentIndex(index.parent())
 
             # Otherwise, do this for collapsed directories only
@@ -430,6 +432,7 @@ class DraggableTreeMixin(TreeMixin):
     Expects that the widget provides an `items_moved` signal.
 
     """
+
     def __init__(self, widget, Base):
         super(DraggableTreeMixin, self).__init__(widget, Base)
 
@@ -636,6 +639,7 @@ class ProgressDialog(QtWidgets.QProgressDialog):
     A thread is spawned to animate the progress label text.
 
     """
+
     def __init__(self, title, label, parent):
         QtWidgets.QProgressDialog.__init__(self, parent)
         if parent is not None:
@@ -678,6 +682,7 @@ class ProgressAnimationThread(QtCore.QThread):
     """Emits a pseudo-animated text stream for progress bars
 
     """
+
     updated = Signal(object)
 
     def __init__(self, txt, parent, timeout=0.1):
@@ -712,9 +717,9 @@ class ProgressAnimationThread(QtCore.QThread):
 
 
 class SpinBox(QtWidgets.QSpinBox):
-
-    def __init__(self, parent=None, value=None,
-                 mini=1, maxi=99999, step=0, prefix='', suffix=''):
+    def __init__(
+        self, parent=None, value=None, mini=1, maxi=99999, step=0, prefix='', suffix=''
+    ):
         QtWidgets.QSpinBox.__init__(self, parent)
         self.setPrefix(prefix)
         self.setSuffix(suffix)
@@ -763,9 +768,21 @@ class MessageBox(Dialog):
     to workaround, so we use a simple custom dialog instead.
 
     """
-    def __init__(self, parent=None, title='', text='',
-                 info='', details='', logo=None, default=False,
-                 ok_icon=None, ok_text='', cancel_text=None, cancel_icon=None):
+
+    def __init__(
+        self,
+        parent=None,
+        title='',
+        text='',
+        info='',
+        details='',
+        logo=None,
+        default=False,
+        ok_icon=None,
+        ok_text='',
+        cancel_text=None,
+        cancel_icon=None,
+    ):
 
         Dialog.__init__(self, parent=parent)
 
@@ -794,8 +811,7 @@ class MessageBox(Dialog):
         ok_icon = icons.mkicon(ok_icon, icons.ok)
         self.button_ok = qtutils.create_button(text=ok_text, icon=ok_icon)
 
-        self.button_close = qtutils.close_button(
-            text=cancel_text, icon=cancel_icon)
+        self.button_close = qtutils.close_button(text=cancel_text, icon=cancel_icon)
 
         if ok_text:
             self.button_ok.setText(ok_text)
@@ -811,22 +827,36 @@ class MessageBox(Dialog):
             self.details_text.hide()
 
         self.info_layout = qtutils.vbox(
-            defs.large_margin, defs.button_spacing,
-            self.text_label, self.info_label, qtutils.STRETCH)
+            defs.large_margin,
+            defs.button_spacing,
+            self.text_label,
+            self.info_label,
+            qtutils.STRETCH,
+        )
 
         self.top_layout = qtutils.hbox(
-            defs.large_margin, defs.button_spacing,
-            self.logo_label, self.info_layout, qtutils.STRETCH)
+            defs.large_margin,
+            defs.button_spacing,
+            self.logo_label,
+            self.info_layout,
+            qtutils.STRETCH,
+        )
 
         self.buttons_layout = qtutils.hbox(
-            defs.no_margin, defs.button_spacing, qtutils.STRETCH,
-            self.button_close, self.button_ok)
+            defs.no_margin,
+            defs.button_spacing,
+            qtutils.STRETCH,
+            self.button_close,
+            self.button_ok,
+        )
 
         self.main_layout = qtutils.vbox(
-            defs.margin, defs.button_spacing,
+            defs.margin,
+            defs.button_spacing,
             self.top_layout,
             self.buttons_layout,
-            self.details_text)
+            self.details_text,
+        )
         self.main_layout.setStretchFactor(self.details_text, 2)
         self.setLayout(self.main_layout)
 
@@ -868,18 +898,32 @@ class MessageBox(Dialog):
         return self.exec_()
 
 
-def confirm(title, text, informative_text, ok_text,
-            icon=None, default=True,
-            cancel_text=None, cancel_icon=None):
+def confirm(
+    title,
+    text,
+    informative_text,
+    ok_text,
+    icon=None,
+    default=True,
+    cancel_text=None,
+    cancel_icon=None,
+):
     """Confirm that an action should take place"""
     cancel_text = cancel_text or N_('Cancel')
     logo = icons.from_style(QtWidgets.QStyle.SP_MessageBoxQuestion)
 
     mbox = MessageBox(
-        parent=qtutils.active_window(), title=title, text=text,
-        info=informative_text, ok_text=ok_text, ok_icon=icon,
-        cancel_text=cancel_text, cancel_icon=cancel_icon,
-        logo=logo, default=default)
+        parent=qtutils.active_window(),
+        title=title,
+        text=text,
+        info=informative_text,
+        ok_text=ok_text,
+        ok_icon=icon,
+        cancel_text=cancel_text,
+        cancel_icon=cancel_icon,
+        logo=logo,
+        default=default,
+    )
 
     return mbox.run() == mbox.Accepted
 
@@ -890,8 +934,12 @@ def critical(title, message=None, details=None):
         message = title
     logo = icons.from_style(QtWidgets.QStyle.SP_MessageBoxCritical)
     mbox = MessageBox(
-        parent=qtutils.active_window(), title=title, text=message,
-        details=details, logo=logo)
+        parent=qtutils.active_window(),
+        title=title,
+        text=message,
+        details=details,
+        logo=logo,
+    )
     mbox.run()
 
 
@@ -907,8 +955,13 @@ def information(title, message=None, details=None, informative_text=None):
     if message is None:
         message = title
     mbox = MessageBox(
-        parent=qtutils.active_window(), title=title, text=message,
-        info=informative_text, details=details, logo=icons.cola())
+        parent=qtutils.active_window(),
+        title=title,
+        text=message,
+        info=informative_text,
+        details=details,
+        logo=icons.cola(),
+    )
     mbox.run()
 
 
@@ -923,8 +976,14 @@ def question(title, text, default=True):
     parent = qtutils.active_window()
     logo = icons.from_style(QtWidgets.QStyle.SP_MessageBoxQuestion)
     msgbox = MessageBox(
-        parent=parent, title=title, text=text, default=default, logo=logo,
-        ok_text=N_('Yes'), cancel_text=N_('No'))
+        parent=parent,
+        title=title,
+        text=text,
+        default=default,
+        logo=logo,
+        ok_text=N_('Yes'),
+        cancel_text=N_('No'),
+    )
     return msgbox.run() == msgbox.Accepted
 
 
