@@ -9,6 +9,7 @@ from qtpy import QtWidgets
 from qtpy.QtCore import Qt
 from qtpy.QtCore import Signal
 
+from ..models import prefs
 from ..qtutils import get
 from .. import hotkeys
 from .. import qtutils
@@ -20,39 +21,6 @@ def get_stripped(widget):
     return widget.get().strip()
 
 
-# PyQt4 does not provide QProxyStyle -- this is a drop-in replacement
-class ProxyStyle(QtWidgets.QCommonStyle):
-
-    OVERRIDES = set()
-
-    def __init__(self, style):
-        super(ProxyStyle, self).__init__()
-        for name, value in style.__dict__.items():
-            if name not in self.OVERRIDES:
-                setattr(self, name, value)
-
-
-if hasattr(QtWidgets, 'QProxyStyle'):
-    BaseProxyStyle = QtWidgets.QProxyStyle  # pylint: disable=no-member
-else:
-    BaseProxyStyle = ProxyStyle
-
-
-class LineEditStyle(BaseProxyStyle):
-
-    OVERRIDES = set(['pixelMetric'])
-
-    def __init__(self, widget):
-        super(LineEditStyle, self).__init__(widget.style())
-        self.widget = widget
-
-    def pixelMetric(self, metric, option, widget):
-        if metric == QtWidgets.QStyle.PM_TextCursorWidth:
-            font = self.widget.font()
-            return QtGui.QFontMetrics(font).width('M')
-        return super(LineEditStyle, self).pixelMetric(metric, option, widget)
-
-
 class LineEdit(QtWidgets.QLineEdit):
 
     cursor_changed = Signal(int, int)
@@ -68,8 +36,6 @@ class LineEdit(QtWidgets.QLineEdit):
         if clear_button and hasattr(self, 'setClearButtonEnabled'):
             self.setClearButtonEnabled(True)
 
-        self.setStyle(LineEditStyle(self))
-
     def get(self):
         """Return the raw unicode value from Qt"""
         return self.text()
@@ -91,6 +57,7 @@ class LineEdit(QtWidgets.QLineEdit):
 class LineEditCursorPosition(object):
     """Translate cursorPositionChanged(int,int) into cursorPosition(int,int)
     """
+
     def __init__(self, widget, row):
         self._widget = widget
         self._row = row
@@ -108,7 +75,6 @@ class LineEditCursorPosition(object):
 
 
 class BaseTextEditExtension(QtCore.QObject):
-
     def __init__(self, widget, get_value, readonly):
         QtCore.QObject.__init__(self, widget)
         self.widget = widget
@@ -131,8 +97,9 @@ class BaseTextEditExtension(QtCore.QObject):
             widget.setAcceptDrops(False)
             widget.setTabChangesFocus(True)
             widget.setUndoRedoEnabled(False)
-            widget.setTextInteractionFlags(Qt.TextSelectableByKeyboard |
-                                           Qt.TextSelectableByMouse)
+            widget.setTextInteractionFlags(
+                Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
+            )
 
     def get(self):
         """Return the raw unicode value from Qt"""
@@ -159,8 +126,7 @@ class BaseTextEditExtension(QtCore.QObject):
             idx = value.index(selection_text)
             cursor = self.widget.textCursor()
             cursor.setPosition(idx)
-            cursor.setPosition(idx + len(selection_text),
-                               QtGui.QTextCursor.KeepAnchor)
+            cursor.setPosition(idx + len(selection_text), QtGui.QTextCursor.KeepAnchor)
             self.widget.setTextCursor(cursor)
 
         elif value == old_value:
@@ -200,10 +166,8 @@ class BaseTextEditExtension(QtCore.QObject):
     def selected_line(self):
         contents = self.value()
         cursor = self.widget.textCursor()
-        offset = min(cursor.position(), len(contents)-1)
-        while (offset >= 1 and
-               contents[offset-1] and
-               contents[offset-1] != '\n'):
+        offset = min(cursor.position(), len(contents) - 1)
+        while offset >= 1 and contents[offset - 1] and contents[offset - 1] != '\n':
             offset -= 1
         data = contents[offset:]
         if '\n' in data:
@@ -235,27 +199,23 @@ class BaseTextEditExtension(QtCore.QObject):
 
     # For extension by sub-classes
 
+    # pylint: disable=no-self-use
     def init(self):
         """Called during init for class-specific settings"""
-        pass
+        return
 
+    # pylint: disable=no-self-use,unused-argument
     def set_textwidth(self, width):
         """Set the text width"""
-        pass
+        return
 
+    # pylint: disable=no-self-use,unused-argument
     def set_linebreak(self, brk):
         """Enable word wrapping"""
-        pass
-
-    def set_font(self, font):
-        # Update cursor width
-        metrics = QtGui.QFontMetrics(font)
-        width = metrics.width('M')
-        self.widget.setCursorWidth(width)
+        return
 
 
 class PlainTextEditExtension(BaseTextEditExtension):
-
     def set_linebreak(self, brk):
         if brk:
             wrapmode = QtWidgets.QPlainTextEdit.WidgetWidth
@@ -315,13 +275,8 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
             return
         super(PlainTextEdit, self).wheelEvent(event)
 
-    def setFont(self, font):
-        super(PlainTextEdit, self).setFont(font)
-        self.ext.set_font(font)
-
 
 class TextEditExtension(BaseTextEditExtension):
-
     def init(self):
         widget = self.widget
         widget.setAcceptRichText(False)
@@ -374,10 +329,6 @@ class TextEdit(QtWidgets.QTextEdit):
     def set_expandtab(self, value):
         self.expandtab_enabled = value
 
-    def setFont(self, font):
-        super(TextEdit, self).setFont(font)
-        self.ext.set_font(font)
-
     def mousePressEvent(self, event):
         self.ext.mouse_press_event(event)
         super(TextEdit, self).mousePressEvent(event)
@@ -414,7 +365,6 @@ class TextEdit(QtWidgets.QTextEdit):
 
 
 class TextEditCursorPosition(object):
-
     def __init__(self, widget, ext):
         self._widget = widget
         self._ext = ext
@@ -431,7 +381,7 @@ class TextEditCursorPosition(object):
         line = before.split('\n')[row]
         col = cursor.columnNumber()
         col += line[:col].count('\t') * (ext.tabwidth() - 1)
-        widget.cursor_changed.emit(row+1, col)
+        widget.cursor_changed.emit(row + 1, col)
 
     def reset(self):
         widget = self._widget
@@ -441,7 +391,6 @@ class TextEditCursorPosition(object):
 
 
 class MonoTextEdit(PlainTextEdit):
-
     def __init__(self, context, parent=None, readonly=False):
         PlainTextEdit.__init__(self, parent=parent, readonly=readonly)
         self.setFont(qtutils.diff_font(context))
@@ -485,25 +434,33 @@ class HintWidget(QtCore.QObject):
         error_bg_rgb = qtutils.rgb_css(error_bg_color)
         error_fg_rgb = qtutils.rgb_css(error_fg_color)
 
-        env = dict(name=widget.__class__.__name__,
-                   error_fg_rgb=error_fg_rgb,
-                   error_bg_rgb=error_bg_rgb,
-                   hint_rgb=hint_rgb)
+        env = dict(
+            name=widget.__class__.__name__,
+            error_fg_rgb=error_fg_rgb,
+            error_bg_rgb=error_bg_rgb,
+            hint_rgb=hint_rgb,
+        )
 
         self._default_style = ''
 
-        self._hint_style = """
+        self._hint_style = (
+            """
             %(name)s {
                 color: %(hint_rgb)s;
             }
-        """ % env
+        """
+            % env
+        )
 
-        self._error_style = """
+        self._error_style = (
+            """
             %(name)s {
                 color: %(error_fg_rgb)s;
                 background-color: %(error_bg_rgb)s;
             }
-        """ % env
+        """
+            % env
+        )
 
     def init(self):
         """Defered initialization"""
@@ -564,7 +521,7 @@ class HintWidget(QtCore.QObject):
             style = self._hint_style
         else:
             style = self._default_style
-        self._widget.setStyleSheet(style)
+        QtCore.QTimer.singleShot(0, lambda: self._widget.setStyleSheet(style))
 
     def eventFilter(self, _obj, event):
         """Enable/disable hint-mode when focus changes"""
@@ -593,13 +550,15 @@ class HintedPlainTextEdit(PlainTextEdit):
     """A hinted plain text edit"""
 
     def __init__(self, context, hint, parent=None, readonly=False):
-        PlainTextEdit.__init__(self, parent=parent,
-                               get_value=get_value_hinted,
-                               readonly=readonly)
+        PlainTextEdit.__init__(
+            self, parent=parent, get_value=get_value_hinted, readonly=readonly
+        )
         self.hint = HintWidget(self, hint)
         self.hint.init()
         self.setFont(qtutils.diff_font(context))
+        self.set_tabwidth(prefs.tabwidth(context))
         # Refresh palettes when text changes
+        # pylint: disable=no-member
         self.textChanged.connect(self.hint.refresh)
 
     def set_value(self, value, block=False):
@@ -614,11 +573,13 @@ class HintedTextEdit(TextEdit):
     """A hinted text edit"""
 
     def __init__(self, context, hint, parent=None, readonly=False):
-        TextEdit.__init__(self, parent=parent,
-                          get_value=get_value_hinted, readonly=readonly)
+        TextEdit.__init__(
+            self, parent=parent, get_value=get_value_hinted, readonly=readonly
+        )
         self.hint = HintWidget(self, hint)
         self.hint.init()
         # Refresh palettes when text changes
+        # pylint: disable=no-member
         self.textChanged.connect(self.hint.refresh)
         self.setFont(qtutils.diff_font(context))
 
@@ -632,42 +593,44 @@ class HintedTextEdit(TextEdit):
 
 # The vim-like read-only text view
 
-class VimMixin(object):
 
+class VimMixin(object):
     def __init__(self, widget):
         self.widget = widget
         self.Base = widget.Base
         # Common vim/unix-ish keyboard actions
-        self.add_navigation('Up', hotkeys.MOVE_UP,
-                            shift=hotkeys.MOVE_UP_SHIFT)
-        self.add_navigation('Down', hotkeys.MOVE_DOWN,
-                            shift=hotkeys.MOVE_DOWN_SHIFT)
-        self.add_navigation('Left', hotkeys.MOVE_LEFT,
-                            shift=hotkeys.MOVE_LEFT_SHIFT)
-        self.add_navigation('Right', hotkeys.MOVE_RIGHT,
-                            shift=hotkeys.MOVE_RIGHT_SHIFT)
+        self.add_navigation('Up', hotkeys.MOVE_UP, shift=hotkeys.MOVE_UP_SHIFT)
+        self.add_navigation('Down', hotkeys.MOVE_DOWN, shift=hotkeys.MOVE_DOWN_SHIFT)
+        self.add_navigation('Left', hotkeys.MOVE_LEFT, shift=hotkeys.MOVE_LEFT_SHIFT)
+        self.add_navigation('Right', hotkeys.MOVE_RIGHT, shift=hotkeys.MOVE_RIGHT_SHIFT)
         self.add_navigation('WordLeft', hotkeys.WORD_LEFT)
         self.add_navigation('WordRight', hotkeys.WORD_RIGHT)
         self.add_navigation('StartOfLine', hotkeys.START_OF_LINE)
         self.add_navigation('EndOfLine', hotkeys.END_OF_LINE)
 
-        qtutils.add_action(widget, 'PageUp',
-                           lambda: widget.page(-widget.height()//2),
-                           hotkeys.SECONDARY_ACTION)
+        qtutils.add_action(
+            widget,
+            'PageUp',
+            lambda: widget.page(-widget.height() // 2),
+            hotkeys.SECONDARY_ACTION,
+        )
 
-        qtutils.add_action(widget, 'PageDown',
-                           lambda: widget.page(widget.height()//2),
-                           hotkeys.PRIMARY_ACTION)
+        qtutils.add_action(
+            widget,
+            'PageDown',
+            lambda: widget.page(widget.height() // 2),
+            hotkeys.PRIMARY_ACTION,
+        )
 
     def add_navigation(self, name, hotkey, shift=None):
         """Add a hotkey along with a shift-variant"""
         widget = self.widget
         direction = getattr(QtGui.QTextCursor, name)
-        qtutils.add_action(widget, name,
-                           lambda: self.move(direction), hotkey)
+        qtutils.add_action(widget, name, lambda: self.move(direction), hotkey)
         if shift:
-            qtutils.add_action(widget, 'Shift' + name,
-                               lambda: self.move(direction, True), shift)
+            qtutils.add_action(
+                widget, 'Shift' + name, lambda: self.move(direction, True), shift
+            )
 
     def move(self, direction, select=False, n=1):
         widget = self.widget
@@ -728,18 +691,19 @@ class VimMixin(object):
         return self.Base.keyPressEvent(widget, event)
 
 
+# pylint: disable=too-many-ancestors
 class VimHintedPlainTextEdit(HintedPlainTextEdit):
     """HintedPlainTextEdit with vim hotkeys
 
     This can only be used in read-only mode.
 
     """
+
     Base = HintedPlainTextEdit
     Mixin = VimMixin
 
     def __init__(self, context, hint, parent=None):
-        HintedPlainTextEdit.__init__(
-            self, context, hint, parent=parent, readonly=True)
+        HintedPlainTextEdit.__init__(self, context, hint, parent=parent, readonly=True)
         self._mixin = self.Mixin(self)
 
     def move(self, direction, select=False, n=1):
@@ -752,12 +716,14 @@ class VimHintedPlainTextEdit(HintedPlainTextEdit):
         return self._mixin.keyPressEvent(event)
 
 
+# pylint: disable=too-many-ancestors
 class VimTextEdit(MonoTextEdit):
     """Text viewer with vim-like hotkeys
 
     This can only be used in read-only mode.
 
     """
+
     Base = MonoTextEdit
     Mixin = VimMixin
 
@@ -776,12 +742,12 @@ class VimTextEdit(MonoTextEdit):
 
 
 class HintedLineEdit(LineEdit):
-
     def __init__(self, context, hint, parent=None):
         LineEdit.__init__(self, parent=parent, get_value=get_value_hinted)
         self.hint = HintWidget(self, hint)
         self.hint.init()
         self.setFont(qtutils.diff_font(context))
+        # pylint: disable=no-member
         self.textChanged.connect(lambda text: self.hint.refresh())
 
 
@@ -806,8 +772,9 @@ def text_dialog(context, text, title):
     layout = qtutils.hbox(defs.margin, defs.spacing, scroll)
     widget.setLayout(layout)
 
-    qtutils.add_action(widget, N_('Close'), widget.accept,
-                       Qt.Key_Question, Qt.Key_Enter, Qt.Key_Return)
+    qtutils.add_action(
+        widget, N_('Close'), widget.accept, Qt.Key_Question, Qt.Key_Enter, Qt.Key_Return
+    )
     widget.show()
     return widget
 
@@ -854,8 +821,7 @@ class TextDecorator(QtWidgets.QWidget):
 
     def refresh_size(self):
         rect = self.editor.contentsRect()
-        geom = QtCore.QRect(rect.left(), rect.top(),
-                            self.width_hint(), rect.height())
+        geom = QtCore.QRect(rect.left(), rect.top(), self.width_hint(), rect.height())
         self.setGeometry(geom)
 
     def sizeHint(self):
@@ -905,16 +871,18 @@ class LineNumbers(TextDecorator):
             rect = block_geom.translated(content_offset).toRect()
             block_number = block.blockNumber()
             if block_number == self.highlight_line:
-                painter.fillRect(rect.x(), rect.y(),
-                                 width, rect.height(), highlight)
+                painter.fillRect(rect.x(), rect.y(), width, rect.height(), highlight)
                 painter.setPen(highlighted_text)
             else:
                 painter.setPen(disabled)
 
             number = '%s' % (block_number + 1)
-            painter.drawText(rect.x(), rect.y(),
-                             self.width() - defs.large_margin,
-                             rect.height(),
-                             Qt.AlignRight | Qt.AlignVCenter,
-                             number)
+            painter.drawText(
+                rect.x(),
+                rect.y(),
+                self.width() - defs.large_margin,
+                rect.height(),
+                Qt.AlignRight | Qt.AlignVCenter,
+                number,
+            )
             block = block.next()  # pylint: disable=next-method-called
